@@ -6,7 +6,7 @@ from uniplot.axis_labels.label_set import LabelSet
 # Preference-ordered list of "nice" numbers
 Q_VALUES = [1, 5, 2, 2.5, 4, 3]
 # Weights to be able to combine the different scores
-WEIGHTS = np.array([0.2, 0.2, 0.4, 0.2])
+WEIGHTS = np.array([0.25, 0.25, 0.3, 0.2])
 # The "depth" of the search
 MAX_SKIP_AMOUNT = 9
 
@@ -28,10 +28,9 @@ def extended_talbot_labels(
     data_range: float = x_max - x_min
     base_exponent = int(np.log10(data_range))
 
-    # HACK Set the preferred number of labels
-    preferred_number_of_labels = int(available_space / 4)
-    if vertical_direction is False:
-        preferred_number_of_labels = int(available_space / 15)
+    preferred_nr_labels = _compute_preferred_numer_of_labels(
+        available_space, vertical_direction
+    )
 
     for exponent in [base_exponent, base_exponent - 1]:
         x_min_normalized = int(np.floor(x_min / 10 ** exponent))
@@ -63,7 +62,7 @@ def extended_talbot_labels(
 
                     simplicity = _compute_simplicity_score(labels, i, j)
                     coverage = _compute_coverage_score(labels, x_min, x_max)
-                    density = _compute_density_score(labels, preferred_number_of_labels)
+                    density = _compute_density_score(labels, preferred_nr_labels)
 
                     # Performance improvement
                     if (
@@ -109,6 +108,22 @@ def extended_talbot_labels(
 ###########
 
 
+def _compute_preferred_numer_of_labels(
+    available_space: int, vertical_direction: bool
+) -> int:
+    """
+    Compute an estimate for the preferred number of labels.
+    """
+    # For horizontal direction (x axis)
+    preferred_number_of_labels = int(available_space / 15)
+
+    if vertical_direction:
+        # for y axis
+        preferred_number_of_labels = int(available_space / 5)
+
+    return max(2, min(20, preferred_number_of_labels))
+
+
 def _compute_simplicity_score(labels, i: int, j: int) -> float:
     """
     Simplicity score according to Talbot.
