@@ -7,6 +7,10 @@ def _default_gridlines() -> List[float]:
     return [0.0]
 
 
+def _default_lines() -> List[bool]:
+    return [False]
+
+
 @dataclass
 class Options:
     # Color mode
@@ -18,23 +22,23 @@ class Options:
     # Labels for the series
     legend_labels: Optional[List[str]] = None
     # Draw lines between points
-    lines: bool = False
+    lines: List[bool] = field(default_factory=_default_lines)
     # Title of the plot
     title: Optional[str] = None
     # Width of the plotting region, in characters
     width: int = 60
     # Vertical gridlines
     x_gridlines: List[float] = field(default_factory=_default_gridlines)
-    # Minimum x value of the current view
-    x_min: float = 0.0
     # Maximum x value of the current view
     x_max: float = 1.0
+    # Minimum x value of the current view
+    x_min: float = 0.0
     # Horizontal gridlines
     y_gridlines: List[float] = field(default_factory=_default_gridlines)
-    # Minimum y value of the current view
-    y_min: float = 0.0
     # Maximum y value of the current view
     y_max: float = 1.0
+    # Minimum y value of the current view
+    y_min: float = 0.0
 
     def __post_init__(self):
         # Validate values
